from django.contrib.auth.tokens import PasswordResetTokenGenerator
from six import text_type

class AccountActivationTokenGenerator(PasswordResetTokenGenerator):

    def _make_hash_value(self, user, timestamp):
        return (text_type(user.pk) + text_type(timestamp) + text_type(user.is_active))


account_activation_token = AccountActivationTokenGenerator()


from django.utils import timezone
from .models import Content

def schedule_blogpost():
    bulk_post=Content.objects.filter(is_schedule=True)
    current_time = timezone.now()
    if bulk_post.exists():
        for post in bulk_post:
            if current_time > post.schedule:
                post.status = 'Publish'
                post.save()
    else:
        pass

def task2():
    return


# Generated by Django 5.0 on 2023-12-21 20:23

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0018_jobapplication_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='jobapplication',
            name='available_start_date',
        ),
        migrations.AddField(
            model_name='jobapplication',
            name='availability',
            field=models.CharField(choices=[('', 'Choose One'), ('Part-Time', 'Part-Time'), ('Full-Time', 'Full-Time'), ('Internship', 'Internship'), ('Freelance', 'Freelance')], default='Choose One', max_length=100),
        ),
        migrations.AddField(
            model_name='jobapplication',
            name='cv',
            field=models.FileField(blank=True, null=True, upload_to='cv/'),
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('IT Development Services', 'IT Development Services'), ('E-commerce', 'E-commerce'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Health and Wellness', 'Health and Wellness'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Consulting', 'Consulting'), ('Media Creators', 'Media Creators'), ('Education and Training', 'Education and Training'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Restaurants and Food Services', 'Restaurants and Food Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-danger', 'card-light-danger'), ('card-dark-blue', 'card-dark-blue'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Interviews', 'Interviews'), ('Tutorials', 'Tutorials'), ('Tips and Tricks', 'Tips and Tricks'), ('Events and Conferences', 'Events and Conferences'), ('Inspiration', 'Inspiration'), ('News', 'News'), ('Guides and Manuals', 'Guides and Manuals')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 21, 17, 22, 11, 637446)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount'), ('No Selected', 'No Selected'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription')], max_length=60),
        ),
        migrations.AlterField(
            model_name='jobapplication',
            name='address',
            field=models.CharField(max_length=300, verbose_name='Address'),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Domains', 'Cloud Domains'), ('No Selected', 'No Selected'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing'), ('Stela Design', 'Stela Design'), ('Stela Websites', 'Stela Websites')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('budget_design_terms', 'Budget Design Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('Disclaimer', 'Disclaimer'), ('budget_development_terms', 'Budget Development Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Return Policy', 'Return Policy'), ('Cookie Policy', 'Cookie Policy'), ('Privacy Policy', 'Privacy Policy'), ('monthly_terms', 'Billing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Youtube', 'Youtube'), ('Instagram', 'Instagram'), ('Wikipedia', 'Wikipedia'), ('Facebook', 'Facebook'), ('Tiktok', 'Tiktok'), ('X', 'X'), ('Linkedin', 'Linkedin'), ('Github', 'Github')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Others', 'Others'), ('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my project', 'I have a problem with my project')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True),
        ),
    ]



# Generated by Django 4.2.1 on 2023-11-13 02:38

import autoslug.fields
import cities_light.abstract_models
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('name_ascii', models.CharField(blank=True, db_index=True, max_length=200)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='name_ascii')),
                ('geoname_id', models.IntegerField(blank=True, null=True, unique=True)),
                ('alternate_names', models.TextField(blank=True, default='', null=True)),
                ('code2', models.CharField(blank=True, max_length=2, null=True, unique=True)),
                ('code3', models.CharField(blank=True, max_length=3, null=True, unique=True)),
                ('continent', models.CharField(choices=[('OC', 'Oceania'), ('EU', 'Europe'), ('AF', 'Africa'), ('NA', 'North America'), ('AN', 'Antarctica'), ('SA', 'South America'), ('AS', 'Asia')], db_index=True, max_length=2)),
                ('tld', models.CharField(blank=True, db_index=True, max_length=5)),
                ('phone', models.CharField(blank=True, max_length=20, null=True)),
            ],
            options={
                'verbose_name_plural': 'countries',
                'ordering': ['name'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('name_ascii', models.CharField(blank=True, db_index=True, max_length=200)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='name_ascii')),
                ('geoname_id', models.IntegerField(blank=True, null=True, unique=True)),
                ('alternate_names', models.TextField(blank=True, default='', null=True)),
                ('display_name', models.CharField(max_length=200)),
                ('geoname_code', models.CharField(blank=True, db_index=True, max_length=50, null=True)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='geolocation.country')),
            ],
            options={
                'verbose_name': 'region/state',
                'verbose_name_plural': 'regions/states',
                'ordering': ['name'],
                'abstract': False,
                'unique_together': {('country', 'slug'), ('country', 'name')},
            },
        ),
        migrations.CreateModel(
            name='SubRegion',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('name_ascii', models.CharField(blank=True, db_index=True, max_length=200)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='name_ascii')),
                ('geoname_id', models.IntegerField(blank=True, null=True, unique=True)),
                ('alternate_names', models.TextField(blank=True, default='', null=True)),
                ('display_name', models.CharField(max_length=200)),
                ('geoname_code', models.CharField(blank=True, db_index=True, max_length=50, null=True)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='geolocation.country')),
                ('region', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.region')),
            ],
            options={
                'verbose_name': 'SubRegion',
                'verbose_name_plural': 'SubRegions',
                'ordering': ['name'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('name_ascii', models.CharField(blank=True, db_index=True, max_length=200)),
                ('slug', autoslug.fields.AutoSlugField(editable=False, populate_from='name_ascii')),
                ('geoname_id', models.IntegerField(blank=True, null=True, unique=True)),
                ('alternate_names', models.TextField(blank=True, default='', null=True)),
                ('display_name', models.CharField(max_length=200)),
                ('search_names', cities_light.abstract_models.ToSearchTextField(blank=True, db_index=True, default='', max_length=4000)),
                ('latitude', models.DecimalField(blank=True, decimal_places=5, max_digits=8, null=True)),
                ('longitude', models.DecimalField(blank=True, decimal_places=5, max_digits=8, null=True)),
                ('population', models.BigIntegerField(blank=True, db_index=True, null=True)),
                ('feature_code', models.CharField(blank=True, db_index=True, max_length=10, null=True)),
                ('timezone', models.CharField(max_length=40)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='geolocation.country')),
                ('region', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.region')),
                ('subregion', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.subregion')),
            ],
            options={
                'verbose_name_plural': 'cities',
                'ordering': ['name'],
                'abstract': False,
                'unique_together': {('region', 'subregion', 'name'), ('region', 'subregion', 'slug')},
            },
        ),
    ]



from django.contrib.auth import login, logout, authenticate
from django.contrib.auth.forms import PasswordResetForm
from django.conf import settings
from django.core.mail import send_mail, EmailMultiAlternatives
from django.utils.html import strip_tags
from django.utils import timezone
from django.http.response import JsonResponse
from django.shortcuts import redirect, render
from django.contrib import messages
from stela_control.forms import LoginForm
from stela_control.forms import PwdResetForm, RegistrationForm, UserEditForm, CleanForm, UserLoginForm, PwdResetConfirmForm
from .models import UserBase
from stela_control.models import DataEmail
from django.utils.http import urlsafe_base64_encode, urlsafe_base64_decode
from django.utils.encoding import force_bytes, force_str
from .token import account_activation_token
from django.template.loader import render_to_string
from django.contrib.sites.shortcuts import get_current_site
from django.contrib.auth.decorators import login_required
from django.utils.translation import gettext_lazy as _
import re

# Create your views here.
@login_required
def profile_view(request):
    return render(request, 'link-zone/user/profile/profile.html')

def confirm_view(request):

    return render(request, 'accounts/registration/confirmation_email.html')

def account_register(request):
    date = timezone.now()
    if request.method == 'POST':
        registerForm = RegistrationForm(request.POST)
        if registerForm.is_valid():
            user = registerForm.save(commit=False)
            user.email = registerForm.cleaned_data['email']
            user.set_password(registerForm.cleaned_data['password'])
            user.is_active = False
            user.save()
            if UserBase.objects.filter(newsletter=True):
                 data = DataEmail.objects.filter(email=user.email)
                 if data.exists():
                    pass
                 else:
                    DataEmail.objects.create(
                         email = user.email,
                         date = date
                 ) 
            current_site = get_current_site(request)
            subject = _('Activate your account')
            html_content = render_to_string('emails/registration/confirmation.html', {
                        'user': user,           
                        'domain': current_site.domain,
                        'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                        'token': account_activation_token.make_token(user),
                        })
            text_content = strip_tags(html_content)

            email = EmailMultiAlternatives(
                subject,
                text_content,
                settings.DEFAULT_EMAIL,
                [user.email]
            )
            email.attach_alternative(html_content, "text/html")
            email.send()

            subject = _('New User On Your Site')
            html_content = render_to_string('emails/registration/alert.html', {
                        'user': user,           
                        'domain': current_site.domain,
                        'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                        'token': account_activation_token.make_token(user),
                        })
            text_content = strip_tags(html_content)

            email = EmailMultiAlternatives(
                subject,
                text_content,
                settings.STELA_EMAIL,
                [settings.DEFAULT_EMAIL]
            )
            email.attach_alternative(html_content, "text/html")
            email.send()
            
            return redirect('accounts:confirm')

    else:
        registerForm = RegistrationForm()
    return render(request, 'accounts/registration/register.html',{'form':registerForm})

def request(request):
    action = request.POST.get('action')
    print(action)
    
    if action == "checkEmail":
        pattern = re.compile(r'^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$')
        email = request.POST.get("user_input")
        if UserBase.objects.filter(email=email).exists():
            response = JsonResponse({'error': _('email not available')})
        elif not pattern.match(email):
            response = JsonResponse({'error': _('Invalid email')})
        else:
            response = JsonResponse({'success': _('email available')})
        return response

    if action == "checkUsername":
        username = request.POST.get("user_input")
        if UserBase.objects.filter(username=username).exists():
            response = JsonResponse({'error': _('username not available')})
            
        elif not re.match(r'^[a-z0-9_]+$', username):
            response = JsonResponse({'error': _('invalid username only lower case, numbers and (_) accepted')})
        
        else:
            response = JsonResponse({'success': _('username available')})
        
        return response
        
    if action == "checkPassword":
        password = request.POST.get("password")
        
        if len(password) < 8:
            response = JsonResponse({'error': _('Password must be at least 8 characters long')})
        
        elif not re.match(r'^[a-zA-Z0-9*.$_]+$', password):
            response = JsonResponse({'error': _('Password must contain only alphanumeric and special characters (a-zA-Z0-9*$_.)')})
        
        elif password.isalpha():
            response = JsonResponse({'error': _('Password must contain at least one number')})
            
        else:
            response = JsonResponse({'success': _('Password is valid')})

        return response

    if action == "matchPassword":
        password1 = request.POST.get("password1")
        password2 = request.POST.get("password2")

        if password1 != password2:
            response = JsonResponse({'error': _('Password dismatch.')})
        else:
            response = JsonResponse({'success': _('Password match')})
        return response
    
def clean_address(request):
    user = request.user
    data = UserBase.objects.get(pk=user.id)
    profile = CleanForm(instance=data)

    event = "Clean Address"

    context={
        'event': event,
        'profile': profile
    }

    return render(request, 'accounts/user/clean_user.html',context)

def addressFormStela(request):
    user = request.user
    data = UserBase.objects.get(pk=user.id)
    profile = CleanForm(instance=data)
    form = CleanForm(request.POST, request.FILES, instance=data)
        
    if form.is_valid():
            form = profile.save(commit=False)
            form.user = user
            form.save()
            form.save(using='master')

            return redirect("http://stela.localhost:8000/cart")

def password_reset(request):
    if request.method == 'POST':
        registerForm = PwdResetForm(request.POST)
        if registerForm.is_valid():
            data = registerForm.cleaned_data['email']
            user_email = UserBase.objects.filter(email=data)
            if user_email.exists():
                for user in user_email:

                    current_site = get_current_site(request)
                    subject = _('Password Reset')
                    html_content = render_to_string('emails/registration/password_reset_email.html', {
                                'user': user,       
                                'email': user.email,    
                                'domain': current_site.domain,
                                'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                                'token': account_activation_token.make_token(user),
                                })
                    text_content = strip_tags(html_content)

                    email = EmailMultiAlternatives(
                        subject,
                        text_content,
                        settings.DEFAULT_EMAIL,
                        [user.email]
                    )
                    email.attach_alternative(html_content, "text/html")
                    email.send()

                    messages.success(request, _('We have sent recovery link.'))
                    return redirect('accounts:password_reset_done')
    else:
        registerForm = PwdResetForm()
        
    return render(request, 'accounts/user/password_reset_form.html',{'form':registerForm})

def new_password_activate(request, uidb64, token):
    try:
        uid = force_str(urlsafe_base64_decode(uidb64))
        user = UserBase.objects.get(pk=uid)
    except Exception as e:
        user = None
        print(e)

    if user is not None and account_activation_token.check_token(user, token):
        if request.method == 'POST':
            form = PwdResetConfirmForm(user, request.POST)
            if form.is_valid():
                form.save()
                messages.success(request, _("Your new password has been set."))
                return redirect('/accounts/login/')
            else:
                for error in list(form.errors.values()):
                    messages.error(request, error)

        form = PwdResetConfirmForm(user)
        return render(request, 'accounts/user/password_reset_done.html', {
            'form': form,
            'call': 'password reset granted'
            })
    else:
        messages.error(request, _("Link is expired"))

    messages.error(request, _('Something went wrong, redirecting back to account login'))
    return redirect('/accounts/login/')

def account_activate(request, uidb64, token):
    try:
        uid = force_str(urlsafe_base64_decode(uidb64))
        user = UserBase.objects.get(pk=uid)
    except:
        pass
    if user is not None and account_activation_token.check_token(user, token):
        user.is_active = True
        user.save()
        login(request, user)
        messages.success(request, 'Your account has been activated.')
        return redirect('linkzone:console')
    else:
        return render(request, 'accounts/registration/activation_invalid.html') 

@login_required
def edit_details(request):

    if request.method == 'POST':
        user_form = UserEditForm(instance=request.user, data=request.POST)

        if user_form.is_valid():
            user_form.save()
    else:
        user_form = UserEditForm(instance=request.user)
    return render(request, 'link-zone/user/profile/edit_details.html', {'user_form': user_form}) 

@login_required
def delete_user(request):
    user = UserBase.objects.get(username=request.user)
    user.is_active = False
    user.save()
    logout(request)
    return redirect('accounts:delete_confirm')

def logout_view(request):
    logout(request)
    return redirect('/accounts/login/')



# Generated by Django 4.2.1 on 2023-11-13 22:37

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_design', 'Budget Design'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing'), ('Monthly charge', 'Monthly charge'), ('Billing receipt', 'Billing receipt'), ('Others', 'Others')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('IT Development Services', 'IT Development Services'), ('Consulting', 'Consulting'), ('Media Creators', 'Media Creators'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Health and Wellness', 'Health and Wellness'), ('Education and Training', 'Education and Training')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-dark-blue', 'card-dark-blue'), ('card-tale', 'card-tale'), ('card-light-blue', 'card-light-blue'), ('card-light-danger', 'card-light-danger')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Tips and Tricks', 'Tips and Tricks'), ('Interviews', 'Interviews'), ('Tutorials', 'Tutorials'), ('Guides and Manuals', 'Guides and Manuals'), ('News', 'News'), ('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 11, 13, 19, 36, 58, 762901)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Initial Payment', 'Initial Payment'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Domains', 'Cloud Domains'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 3', 'Step 3'), ('Step 2', 'Step 2'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('budget_design_terms', 'Budget Design Terms'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('monthly_terms', 'Billing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Github', 'Github'), ('Linkedin', 'Linkedin'), ('Instagram', 'Instagram'), ('Tiktok', 'Tiktok'), ('Facebook', 'Facebook'), ('X', 'X'), ('Youtube', 'Youtube')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Others', 'Others'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Zelle', 'Zelle'), ('Binance', 'Binance'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
        migrations.CreateModel(
            name='ProStelaUsage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tokens', models.IntegerField(default=0)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('prompt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='prompt_data', to='stela_control.prosteladata')),
            ],
        ),
    ]



# Generated by Django 4.2.1 on 2023-11-13 02:38

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='CloudStorage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module', models.CharField(max_length=400)),
                ('status', models.CharField(default='Turn Off', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
            ],
        ),
        migrations.CreateModel(
            name='Domains',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(default='Pending', max_length=150)),
                ('name', models.CharField(max_length=150)),
                ('tld', models.CharField(max_length=150)),
                ('price', models.DecimalField(blank=True, decimal_places=2, error_messages={'name': {'max_lenght': 'The price must be between 0 and 9999.99'}}, help_text='Maximun 9999.99', max_digits=6, null=True, verbose_name='Price USD')),
                ('request', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='domainowner', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ResquetsCloud',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module', models.CharField(max_length=400)),
                ('status', models.CharField(default='Turn Off', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('domain', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='recloud', to='cloud.domains')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='requestcloud', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ZoneDNS',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module', models.CharField(max_length=400)),
                ('status', models.CharField(default='Turn Off', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('domain', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='domain', to='cloud.domains')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='zone', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='VirtualCloud',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module', models.CharField(max_length=400)),
                ('status', models.CharField(default='Turn Off', max_length=150)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('domain', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='vdomain', to='cloud.domains')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='virtualcloud', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='UsageCloud',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('usage', models.IntegerField(default=1)),
                ('monthy_cost', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('cloudstorage', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='storage_usage', to='cloud.cloudstorage')),
                ('requestcloud', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='request_usage', to='cloud.resquetscloud')),
                ('virtualcloud', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='virtual_usage', to='cloud.virtualcloud')),
                ('zonadns', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dns_usage', to='cloud.zonedns')),
            ],
        ),
        migrations.AddField(
            model_name='cloudstorage',
            name='domain',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='storage', to='cloud.domains'),
        ),
        migrations.AddField(
            model_name='cloudstorage',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='cloudstorage', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 5.0 on 2023-12-19 15:48

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0015_team_owner_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('Others', 'Others'), ('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge'), ('budget_marketing', 'Budget Marketing'), ('budget_design', 'Budget Design')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('E-commerce', 'E-commerce'), ('IT Development Services', 'IT Development Services'), ('Consulting', 'Consulting'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Media Creators', 'Media Creators'), ('Education and Training', 'Education and Training'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Health and Wellness', 'Health and Wellness')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-dark-blue', 'card-dark-blue'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('News', 'News'), ('Inspiration', 'Inspiration'), ('Interviews', 'Interviews'), ('Tips and Tricks', 'Tips and Tricks'), ('Guides and Manuals', 'Guides and Manuals'), ('Events and Conferences', 'Events and Conferences'), ('Tutorials', 'Tutorials')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 19, 12, 48, 10, 272954)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 4', 'Step 4'), ('Step 3', 'Step 3')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Disclaimer', 'Disclaimer'), ('budget_design_terms', 'Budget Design Terms'), ('billing_terms', 'Monthly Billing Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('Return Policy', 'Return Policy'), ('budget_development_terms', 'Budget Development Terms'), ('monthly_terms', 'Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('Cookie Policy', 'Cookie Policy')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Facebook', 'Facebook'), ('Linkedin', 'Linkedin'), ('Github', 'Github'), ('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('X', 'X'), ('Youtube', 'Youtube'), ('Wikipedia', 'Wikipedia')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Others', 'Others'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue'), ('My delivery has been delayed', 'My delivery has been delayed')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Zelle', 'Zelle'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]



# Generated by Django 4.2.1 on 2023-12-15 20:15

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stela_control', '0011_apistelaclient_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='apistelaclient',
            name='name',
        ),
        migrations.AddField(
            model_name='apistelaclient',
            name='owner',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='api_client', to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('IT Development Services', 'IT Development Services'), ('Media Creators', 'Media Creators'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Health and Wellness', 'Health and Wellness'), ('Consulting', 'Consulting'), ('E-commerce', 'E-commerce'), ('Education and Training', 'Education and Training')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Tips and Tricks', 'Tips and Tricks'), ('News', 'News'), ('Guides and Manuals', 'Guides and Manuals'), ('Tutorials', 'Tutorials'), ('Events and Conferences', 'Events and Conferences'), ('Interviews', 'Interviews')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 15, 17, 15, 1, 459849)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected'), ('Initial Payment', 'Initial Payment')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1'), ('Style Template 4', 'Style Template 4'), ('Style Template 3', 'Style Template 3')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Store', 'Store'), ('Stela Websites', 'Stela Websites'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Domains', 'Cloud Domains'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Design', 'Stela Design')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 4', 'Step 4'), ('Step 3', 'Step 3')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Disclaimer', 'Disclaimer'), ('Return Policy', 'Return Policy'), ('billing_terms', 'Monthly Billing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('Cookie Policy', 'Cookie Policy'), ('budget_design_terms', 'Budget Design Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('monthly_terms', 'Billing Terms'), ('Privacy Policy', 'Privacy Policy')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Github', 'Github'), ('X', 'X'), ('Instagram', 'Instagram'), ('Linkedin', 'Linkedin'), ('Youtube', 'Youtube'), ('Tiktok', 'Tiktok'), ('Facebook', 'Facebook')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Payments Issue', 'Payments Issue'), ('Others', 'Others'), ('My account has an error', 'My account has an error')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True),
        ),
    ]



# Generated by Django 5.0 on 2023-12-19 17:32

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0001_initial'),
        ('geolocation', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='userbase',
            name='terms',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='userbase',
            name='city_profile',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.city', verbose_name='City'),
        ),
    ]



from django.contrib.auth import views as auth_views
from django.urls import path
from django.conf import settings
from django.views.generic import TemplateView
from stela_control.forms import (UserLoginForm, PwdResetForm, PwdResetConfirmForm)
from . import views
    
app_name="accounts"

urlpatterns = [
    #login
    path('login/', auth_views.LoginView.as_view(template_name='accounts/user/login.html', form_class=UserLoginForm), name="login"),
    path('logout/', views.logout_view, name="logout"),
    #register
    path('register/', views.account_register, name="register"),
    path('request/', views.request, name="request"),
    path('clean-address', views.clean_address, name="clean_address"),
    path('stela/clean-address/form/', views.addressFormStela, name="clean_address_form"),
    path('activate/<uidb64>/<token>/', views.account_activate, name="activate"),
    path('register/confirmation/', views.confirm_view, name="confirm"),
    #password reset
    path('password_reset/', views.password_reset, name='password-reset'),
    path('password_reset/password_reset_email_confirm/', TemplateView.as_view(template_name="accounts/user/password_reset_done.html"), name='password_reset_done'),
    path('password_reset_confirm/<uidb64>/<token>/', views.new_password_activate, name="password_reset_confirm"),
    path('password_reset_complete/', TemplateView.as_view(template_name="accounts/user/password_reset_done.html"), name='password_reset_complete'),
    #user profile
    path('profile/', views.profile_view, name="profile"), 
    path('profile/edit/', views.edit_details, name="edit_account"),
    path('profile/delete/', views.delete_user, name="delete_user"),
    path('profile/delete_confirm', TemplateView.as_view(template_name="accounts/delete_user.html"), name="delete_confirm"), 
]


from django.db import models

# Create your models here.
from cities_light.abstract_models import (AbstractCity, AbstractRegion,
    AbstractCountry, AbstractSubRegion)
from cities_light.receivers import connect_default_signals


class Country(AbstractCountry):
    pass
connect_default_signals(Country)

class Region(AbstractRegion):
    pass
connect_default_signals(Region)

class SubRegion(AbstractSubRegion):
    pass
connect_default_signals(SubRegion)

class City(AbstractCity):
    timezone = models.CharField(max_length=40)
connect_default_signals(City)


# Generated by Django 4.2.1 on 2023-12-15 19:21

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0010_remove_booking_service_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='APIStelaClient',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('client_key', models.CharField(max_length=255, unique=True)),
                ('secret_key', models.CharField(max_length=255)),
                ('is_subscriber', models.BooleanField(default=False)),
            ],
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_development', 'Budget Development'), ('Others', 'Others'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Health and Wellness', 'Health and Wellness'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Media Creators', 'Media Creators'), ('Consulting', 'Consulting'), ('Education and Training', 'Education and Training'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('IT Development Services', 'IT Development Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Interviews', 'Interviews'), ('Guides and Manuals', 'Guides and Manuals'), ('News', 'News'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Tutorials', 'Tutorials'), ('Inspiration', 'Inspiration')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 15, 16, 21, 25, 404685)),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Domains', 'Cloud Domains'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected'), ('Stela Marketing', 'Stela Marketing'), ('Store', 'Store'), ('Stela Design', 'Stela Design'), ('Stela Websites', 'Stela Websites')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Disclaimer', 'Disclaimer'), ('Privacy Policy', 'Privacy Policy'), ('billing_terms', 'Monthly Billing Terms'), ('monthly_terms', 'Billing Terms'), ('Return Policy', 'Return Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('budget_design_terms', 'Budget Design Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Github', 'Github'), ('Youtube', 'Youtube'), ('Linkedin', 'Linkedin'), ('Facebook', 'Facebook'), ('X', 'X'), ('Instagram', 'Instagram')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
    ]
